<?php

/**
 * slovak language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 *
 * auth.class language support 
 * installer strings 
 *
 * @author Peter Mydliar <peto.mydliar@gmail.com>
 * @author Martin Michalek <michalek.dev@gmail.com>
 * @author Ondrej Vegh <ov@vsieti.sk> with help of the scholars from Zdruzena stredna skola polygraficka in Bratislava
 * @author Michal Mesko <michal.mesko@gmail.com>
 * @author exusik <exusik@gmail.com>
 * @author Tibor Repček <tiborepcek@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '“';
$lang['doublequoteclosing']    = '”';
$lang['singlequoteopening']    = '‘';
$lang['singlequoteclosing']    = '’';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Upraviť stránku';
$lang['btn_source']            = 'Zobraziť zdroj stránky';
$lang['btn_show']              = 'Zobraziť stránku';
$lang['btn_create']            = 'Vytvoriť stránku';
$lang['btn_search']            = 'Hľadať';
$lang['btn_save']              = 'Uložiť';
$lang['btn_preview']           = 'Náhľad';
$lang['btn_top']               = 'Hore';
$lang['btn_newer']             = '<< novšie';
$lang['btn_older']             = 'staršie >>';
$lang['btn_revs']              = 'Staršie verzie';
$lang['btn_recent']            = 'Posledné úpravy';
$lang['btn_upload']            = 'Nahrať';
$lang['btn_cancel']            = 'Storno';
$lang['btn_index']             = 'Index';
$lang['btn_secedit']           = 'Upraviť';
$lang['btn_login']             = 'Prihlásiť sa';
$lang['btn_logout']            = 'Odhlásiť sa';
$lang['btn_admin']             = 'Admin';
$lang['btn_update']            = 'Aktualizovať';
$lang['btn_delete']            = 'Zmazať';
$lang['btn_back']              = 'Späť';
$lang['btn_backlink']          = 'Spätné odkazy';
$lang['btn_subscribe']         = 'Sledovať zmeny';
$lang['btn_profile']           = 'Aktualizovať profil';
$lang['btn_reset']             = 'Zrušiť';
$lang['btn_resendpwd']         = 'Nastaviť nové heslo';
$lang['btn_draft']             = 'Upraviť koncept';
$lang['btn_recover']           = 'Obnoviť koncept';
$lang['btn_draftdel']          = 'Zmazať koncept';
$lang['btn_revert']            = 'Obnoviť';
$lang['btn_register']          = 'Registrovať';
$lang['btn_apply']             = 'Použiť';
$lang['btn_media']             = 'Správa médií';
$lang['btn_deleteuser']        = 'Zrušiť môj účet';
$lang['btn_img_backto']        = 'Späť na %s';
$lang['btn_mediaManager']      = 'Prezrieť v správcovi médií';
$lang['loggedinas']            = 'Prihlásený(á) ako:';
$lang['user']                  = 'Používateľské meno';
$lang['pass']                  = 'Heslo';
$lang['newpass']               = 'Nové heslo';
$lang['oldpass']               = 'Potvrď aktuálne heslo';
$lang['passchk']               = 'Ešte raz znovu';
$lang['remember']              = 'Zapamätaj si ma';
$lang['fullname']              = 'Celé meno';
$lang['email']                 = 'E-Mail';
$lang['profile']               = 'Používateľský profil';
$lang['badlogin']              = 'Zadané používateľské meno a heslo nie je správne.';
$lang['badpassconfirm']        = 'Ľutujem, heslo bolo nesprávne.';
$lang['minoredit']             = 'Menšie zmeny';
$lang['draftdate']             = 'Koncept automaticky uložený';
$lang['nosecedit']             = 'Stránka bola medzičasom zmenená, informácie o sekcii sú zastaralé a z tohto dôvodu bola nahraná celá stránka.';
$lang['searchcreatepage']      = 'Ak ste nenašli, čo ste hľadali, môžete vytvoriť alebo upraviť stránku %s, ktorá bola nazvaná podľa vášho dopytu.';
$lang['search_fullresults']    = 'Fulltextové výsledky';
$lang['js']['search_toggle_tools'] = 'Zobraziť/Skryť vyhľadávacie nástroje';
$lang['js']['willexpire']      = 'Váš zámok pre editáciu za chvíľu stratí platnosť.\nAby ste predišli konfliktom, stlačte tlačítko Náhľad a zámok sa predĺži.';
$lang['js']['notsavedyet']     = 'Neuložené zmeny budú stratené.
Chcete naozaj pokračovať?';
$lang['js']['searchmedia']     = 'Hľadať súbory';
$lang['js']['keepopen']        = 'Po vybraní súboru ponechať okno otvorené';
$lang['js']['hidedetails']     = 'Skryť detaily';
$lang['js']['mediatitle']      = 'Nastavenia odkazu';
$lang['js']['mediadisplay']    = 'Typ odkazu';
$lang['js']['mediaalign']      = 'Zarovnanie';
$lang['js']['mediasize']       = 'Veľkosť obrázka';
$lang['js']['mediatarget']     = 'Cieľ odkazu';
$lang['js']['mediaclose']      = 'Zatvoriť';
$lang['js']['mediainsert']     = 'Vložiť';
$lang['js']['mediadisplayimg'] = 'Zobraziť obrázok.';
$lang['js']['mediadisplaylnk'] = 'Zobraziť iba odkaz.';
$lang['js']['mediasmall']      = 'Malý';
$lang['js']['mediamedium']     = 'Stredný';
$lang['js']['medialarge']      = 'Veľký';
$lang['js']['mediaoriginal']   = 'Originál';
$lang['js']['medialnk']        = 'Odkaz na stránku s detailným popisom';
$lang['js']['mediadirect']     = 'Priamy odkaz na originál';
$lang['js']['medianolnk']      = 'Žiadny odkaz';
$lang['js']['medianolink']     = 'Bez odkazu na obrázok';
$lang['js']['medialeft']       = 'Zarovnať obrázok vľavo.';
$lang['js']['mediaright']      = 'Zarovnať obrázok vpravo.';
$lang['js']['mediacenter']     = 'Zarovnať obrázok na stred.';
$lang['js']['medianoalign']    = 'Nepoužívať zarovnanie.';
$lang['js']['nosmblinks']      = 'Odkazovanie na zdieľané prostriedky Windows funguje len v Internet Exploreri.\nAj napriek tomu tento odkaz môžete skopírovať a vložiť inde.';
$lang['js']['linkwiz']         = 'Sprievodca odkazmi';
$lang['js']['linkto']          = 'Odkaz na:';
$lang['js']['del_confirm']     = 'Zmazať túto položku?';
$lang['js']['restore_confirm'] = 'Skutočne obnoviť túto verziu?';
$lang['js']['media_diff']      = 'Zobraziť rozdiely:';
$lang['js']['media_diff_both'] = 'Vedľa seba';
$lang['js']['media_diff_opacity'] = 'Presvitaním';
$lang['js']['media_diff_portions'] = 'Potiahnutím';
$lang['js']['media_select']    = 'Vybrať súbory...';
$lang['js']['media_upload_btn'] = 'Nahrať';
$lang['js']['media_done_btn']  = 'Hotovo';
$lang['js']['media_drop']      = 'Pridajte súbory potiahnutím myšou';
$lang['js']['media_cancel']    = 'odstrániť';
$lang['js']['media_overwrt']   = 'Prepísať existujúce súbory';
$lang['search_exact_match']    = 'Presná zhoda';
$lang['search_starts_with']    = 'Začín na';
$lang['search_ends_with']      = 'Končí na';
$lang['search_contains']       = 'Obsahuje';
$lang['search_custom_match']   = 'Vlastný';
$lang['search_any_ns']         = 'Akýkoľvek menný priestor';
$lang['search_any_time']       = 'Kedykoľvek';
$lang['search_past_7_days']    = 'Posledný týždeň';
$lang['search_past_month']     = 'Posledný mesiac';
$lang['search_past_year']      = 'Posledný  rok';
$lang['search_sort_by_hits']   = 'Zoradiť podľa počtu návštev';
$lang['search_sort_by_mtime']  = 'Zoradiť podľa posledných úprav';
$lang['regmissing']            = 'Musíte vyplniť všetky údaje.';
$lang['reguexists']            = 'Používateľ s rovnakým menom je už zaregistrovaný.';
$lang['regsuccess']            = 'Používateľský účet bol vytvorený a heslo zaslané emailom.';
$lang['regsuccess2']           = 'Používateľský účet bol vytvorený.';
$lang['regfail']               = 'Používateľský účet nemôže byť vytvorený.';
$lang['regmailfail']           = 'Zdá sa, že nastala chyba pri posielaní mailu s heslom. Skúste kontaktovať správcu.';
$lang['regbadmail']            = 'Zadaná emailová adresa nie je platná. Pokiaľ si myslíte, že to je zle, skúste kontaktovať správcu.';
$lang['regbadpass']            = 'Zadané heslá nie sú rovnaké, zadajte ich prosím znovu.';
$lang['regpwmail']             = 'Vaše heslo do systému DokuWiki';
$lang['reghere']               = 'Nemáte používateľský účet? Vytvorte si ho';
$lang['profna']                = 'Táto wiki nepodporuje zmenu profilu';
$lang['profnochange']          = 'Žiadne zmeny, nie je čo robiť.';
$lang['profnoempty']           = 'Prázdne meno alebo mailová adresa nie sú povolené.';
$lang['profchanged']           = 'Profil požívateľa bol úspešne zmenený.';
$lang['profnodelete']          = 'Táto wiki neumožňuje zrušenie používateľov.';
$lang['profdeleteuser']        = 'Zrušiť účet';
$lang['profdeleted']           = 'Váš účet bol zrušený v tejto wiki.';
$lang['profconfdelete']        = 'Chcem odstrániť môj účet z tejto wiki. <br/> Táto operácia je nevratná.';
$lang['profconfdeletemissing'] = 'Nebolo zavolené potvrdzovacie políčko';
$lang['proffail']              = 'Profil používateľa nebol aktualizovaný.';
$lang['pwdforget']             = 'Zabudli ste heslo? Získajte nové!';
$lang['resendna']              = 'Táto wiki nepodporuje opätovné zasielanie hesla.';
$lang['resendpwd']             = 'Nastaviť nové heslo pre';
$lang['resendpwdmissing']      = 'Prepáčte, musíte vyplniť všetky polia.';
$lang['resendpwdnouser']       = 'Prepáčte, nemôžeme nájsť zadaného používateľa v databáze.';
$lang['resendpwdbadauth']      = 'Prepáčte, tento autorizačný kód nie je platný. Uistite sa, či ste použili celý autorizačný odkaz.';
$lang['resendpwdconfirm']      = 'Autorizačný odkaz bol zaslaný na e-mail.';
$lang['resendpwdsuccess']      = 'Vaše nové heslo bolo zaslané na e-mail.';
$lang['license']               = 'Ak nie je uvedené inak, obsah tejto wiki je uverejnený pod nasledujúcou licenciou:';
$lang['licenseok']             = 'Poznámka: Zmenou tejto stránky súhlasíte s uverejnením obsahu pod nasledujúcou licenciou:';
$lang['searchmedia']           = 'Hľadať meno súboru:';
$lang['searchmedia_in']        = 'Hľadať v %s';
$lang['txt_upload']            = 'Vyberte súbor ako prílohu:';
$lang['txt_filename']          = 'Uložiť ako (voliteľné):';
$lang['txt_overwrt']           = 'Prepísať existujúci súbor';
$lang['maxuploadsize']         = 'Obmedzenie max. %s na súbor.';
$lang['lockedby']              = 'Práve zamknuté:';
$lang['lockexpire']            = 'Zámok stratí platnosť:';
$lang['rssfailed']             = 'Nastala chyba pri vytváraní tohto RSS: ';
$lang['nothingfound']          = 'Nič nenájdené.';
$lang['mediaselect']           = 'Výber súboru';
$lang['uploadsucc']            = 'Prenos prebehol v poriadku';
$lang['uploadfail']            = 'Chyba pri nahrávaní. Možno kvôli zle nastaveným právam?';
$lang['uploadwrong']           = 'Prenos súboru s takouto príponou nie je dovolený.';
$lang['uploadexist']           = 'Súbor už existuje. Žiadna akcia.';
$lang['uploadbadcontent']      = 'Nahraný obsah sa nezhoduje s príponou súboru %s.';
$lang['uploadspam']            = 'Nahrávanie bolo zablokované spamovým blacklistom.';
$lang['uploadxss']             = 'Nahrávanie bolo zablokované kvôli potenciálnemu škodlivému obsahu.';
$lang['uploadsize']            = 'Nahraný súbor bol príliš veľký. (max %s)';
$lang['deletesucc']            = 'Súbor "%s" bol zmazaný.';
$lang['deletefail']            = '"%s" nie je možné zmazať - skontrolujte oprávnenia.';
$lang['mediainuse']            = 'Súbor "%s" nebol zmazaný - je stále používaný.';
$lang['namespaces']            = 'Menné priestory';
$lang['mediafiles']            = 'Dostupné súbory';
$lang['accessdenied']          = 'Nemáte oprávnenie na zobrazenie požadovanej stránky.';
$lang['mediausage']            = 'Pre odkázanie na súbor použite nasledujúcu syntax:';
$lang['mediaview']             = 'Zobraziť pôvodný súbor';
$lang['mediaroot']             = 'root';
$lang['mediaupload']           = 'Nahrať súbor do aktuálneho menného priestoru. Pre vytvorenie menného podpriestoru, pridajte jeho názov na začiatok mena súboru (oddelený dvojbodkou)';
$lang['mediaextchange']        = 'Prípona súboru bola zmenená z .%s na .%s!';
$lang['reference']             = 'Referencie pre';
$lang['ref_inuse']             = 'Súbor nemôže byť zmazaný, pretože je stále používaný nasledujúcimi stránkami:';
$lang['ref_hidden']            = 'Niektoré referencie sú na stránky, pre ktoré nemáte právo na čítanie';
$lang['hits']                  = '- počet výskytov';
$lang['quickhits']             = 'Zodpovedajúce stránky';
$lang['toc']                   = 'Obsah';
$lang['current']               = 'aktuálne';
$lang['yours']                 = 'Vaša verzia';
$lang['diff']                  = 'Zobraziť rozdiely voči aktuálnej verzii';
$lang['diff2']                 = 'Zobraziť rozdiely medzi vybranými verziami';
$lang['difflink']              = 'Odkaz na tento prehľad zmien';
$lang['diff_type']             = 'Prehľad zmien:';
$lang['diff_inline']           = 'Vnorený';
$lang['diff_side']             = 'Vedľa seba';
$lang['diffprevrev']           = 'Predchádzajúca revízia';
$lang['diffnextrev']           = 'Nasledujúca revízia';
$lang['difflastrev']           = 'Posledná revízia';
$lang['diffbothprevrev']       = 'Obojstranná predošlá revízia';
$lang['diffbothnextrev']       = 'Obojstranná nasledujúca revízia';
$lang['line']                  = 'Riadok';
$lang['breadcrumb']            = 'Cesta:';
$lang['youarehere']            = 'Nachádzate sa:';
$lang['lastmod']               = 'Posledná úprava:';
$lang['by']                    = 'od';
$lang['deleted']               = 'odstránené';
$lang['created']               = 'vytvorené';
$lang['restored']              = 'stará verzia bola obnovená (%s)';
$lang['external_edit']         = 'externá úprava';
$lang['summary']               = 'Komentár k úpravám';
$lang['noflash']               = 'Pre zobrazenie tohto obsahu potrebujete <a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a>.';
$lang['download']              = 'Stiahnuť';
$lang['tools']                 = 'Nástroje';
$lang['user_tools']            = 'Nástroje používateľa';
$lang['site_tools']            = 'Nástoje správy stránok';
$lang['page_tools']            = 'Nástoje stránky';
$lang['skip_to_content']       = 'skok na obsah';
$lang['sidebar']               = 'Bočný panel';
$lang['mail_newpage']          = 'stránka pridaná:';
$lang['mail_changed']          = 'stránka zmenená:';
$lang['mail_subscribe_list']   = 'stránky zmenené v mennom priestore:';
$lang['mail_new_user']         = 'nový používateľ:';
$lang['mail_upload']           = 'nahraný súbor:';
$lang['changes_type']          = 'Prehľad zmien';
$lang['pages_changes']         = 'Stránok';
$lang['media_changes']         = 'Súbory';
$lang['both_changes']          = 'Stránok spolu s média súbormi';
$lang['qb_bold']               = 'Tučné';
$lang['qb_italic']             = 'Kurzíva';
$lang['qb_underl']             = 'Podčiarknutie';
$lang['qb_code']               = 'Neformátovať (zdrojový kód)';
$lang['qb_strike']             = 'Prečiarknutie';
$lang['qb_h1']                 = 'Nadpis 1. úrovne';
$lang['qb_h2']                 = 'Nadpis 2. úrovne';
$lang['qb_h3']                 = 'Nadpis 3. úrovne';
$lang['qb_h4']                 = 'Nadpis 4. úrovne';
$lang['qb_h5']                 = 'Nadpis 5. úrovne';
$lang['qb_h']                  = 'Nadpis';
$lang['qb_hs']                 = 'Zvoliť nadpis';
$lang['qb_hplus']              = 'Nadpis vyššej úrovne';
$lang['qb_hminus']             = 'Nadpis nižšej úrovne';
$lang['qb_hequal']             = 'Nadpis predchádzajúcej úrovne';
$lang['qb_link']               = 'Interný odkaz';
$lang['qb_extlink']            = 'Externý odkaz';
$lang['qb_hr']                 = 'Horizontálna linka';
$lang['qb_ol']                 = 'Číslovaný zoznam';
$lang['qb_ul']                 = 'Nečíslovaný zoznam';
$lang['qb_media']              = 'Vložiť obrázky alebo iné súbory';
$lang['qb_sig']                = 'Vložiť podpis';
$lang['qb_smileys']            = 'Smajlíky';
$lang['qb_chars']              = 'Špeciálne znaky';
$lang['upperns']               = 'návrat do nadradeného menného priestoru';
$lang['metaedit']              = 'Upraviť metainformácie';
$lang['metasaveerr']           = 'Zápis metainformácií zlyhal';
$lang['metasaveok']            = 'Metainformácie uložené';
$lang['img_title']             = 'Titul:';
$lang['img_caption']           = 'Popis:';
$lang['img_date']              = 'Dátum:';
$lang['img_fname']             = 'Názov súboru:';
$lang['img_fsize']             = 'Veľkosť:';
$lang['img_artist']            = 'Fotograf:';
$lang['img_copyr']             = 'Kopírovacie práva:';
$lang['img_format']            = 'Formát:';
$lang['img_camera']            = 'Fotoaparát:';
$lang['img_keywords']          = 'Kľúčové slová:';
$lang['img_width']             = 'Šírka:';
$lang['img_height']            = 'Výška:';
$lang['subscr_subscribe_success'] = 'Používateľ %s bol pridaný do zoznamu hlásení o zmenách %s';
$lang['subscr_subscribe_error'] = 'Chyba pri pridaní používateľa %s do zoznamu hlásení o zmenách %s';
$lang['subscr_subscribe_noaddress'] = 'Vaše prihlasovacie meno nemá priradenú žiadnu email adresu, nemôžete byť pridaný do zoznamu hlásení o zmenách';
$lang['subscr_unsubscribe_success'] = 'Používateľ %s bol odstránený zo zoznamu hlásení o zmenách %s';
$lang['subscr_unsubscribe_error'] = 'Chyba pri odstránení používateľa %s zo zoznamu hlásení o zmenách %s';
$lang['subscr_already_subscribed'] = 'Používateľ %s už je v zozname hlásení o zmenách %s';
$lang['subscr_not_subscribed'] = 'Používateľ %s nie je v zozname hlásení o zmenách %s';
$lang['subscr_m_not_subscribed'] = 'Momentálne nesledujete zmeny aktuálnej stránky alebo menného priestoru.';
$lang['subscr_m_new_header']   = 'Pridať sledovanie zmien';
$lang['subscr_m_current_header'] = 'Aktuálne sledované zmeny';
$lang['subscr_m_unsubscribe']  = 'Nesledovať zmeny';
$lang['subscr_m_subscribe']    = 'Sledovať zmeny';
$lang['subscr_m_receive']      = 'Dostávať';
$lang['subscr_style_every']    = 'email pri každej zmene';
$lang['subscr_style_digest']   = 'email so zhrnutím zmien pre každú stránku (perióda %.2f dňa)';
$lang['subscr_style_list']     = 'zoznam zmenených stránok od posledného emailu (perióda %.2f dňa)';
$lang['authtempfail']          = 'Používateľská autentifikácia je dočasne nedostupná. Ak táto situácia pretrváva, prosím informujte správcu systému.';
$lang['i_chooselang']          = 'Zvoľte váš jazyk';
$lang['i_installer']           = 'DokuWiki inštalátor';
$lang['i_wikiname']            = 'Názov Wiki';
$lang['i_enableacl']           = 'Aktivovať ACL (doporučené)';
$lang['i_superuser']           = 'Správca';
$lang['i_problems']            = 'Inštalátor narazil na nižšie uvedené problémy. Nemôžete pokračovať, pokiaľ ich neodstránite.';
$lang['i_modified']            = 'Z bezpečnostných dôvodov bude tento skript fungovať iba s novou, neupravenou inštaláciou Dokuwiki. Môžete buď znovu rozbaliť stiahnutý inštalačný balík alebo preštudovať <a href="http://dokuwiki.org/install"> inštalačné inštrukcie Dokuwiki</a>';
$lang['i_funcna']              = 'PHP funkcia <code>%s</code> nie je dostupná. Je možné, že ju z určitých dôvodov zablokoval váš poskytovateľ webhostingu?';
$lang['i_phpver']              = 'Vaša verzia PHP <code>%s</code> je nižšia ako požadovaná <code>%s</code>. Potrebujete aktualizovať Vašu inštaláciu PHP.';
$lang['i_mbfuncoverload']      = 'mbstring.func_overload musí byt zakázaná v php.ini pre bezproblémový chod DokuWiki.';
$lang['i_permfail']            = '<code>%s</code> nie je zapisovateľný pre DokuWiki. Musíte zmeniť prístupové práva pre tento adresár!';
$lang['i_confexists']          = '<code>%s</code> už existuje';
$lang['i_writeerr']            = 'Nie je možné vytvoriť <code>%s</code>. Potrebujete skontrolovať prístupové práva pre adresár/súbor a vytvoriť ho manuálne.';
$lang['i_badhash']             = 'neznámy alebo zmenený súbor dokuwiki.php (hash=<code>%s</code>)';
$lang['i_badval']              = '<code>%s</code> - nesprávna alebo žiadna hodnota';
$lang['i_success']             = 'Konfigurácia bola úspešne ukončená. Teraz môžete zmazať súbor install.php. Pokračujte vo <a href="doku.php?id=wiki:welcome">vašej novej DokuWiki</a>.';
$lang['i_failure']             = 'Pri zápise konfiguračného súboru nastali nejaké chyby. Potrebujete ich opraviť manuálne pred tým, ako budete môcť používať <a href="doku.php?id=wiki:welcome">vašu novú DokuWiki</a>.';
$lang['i_policy']              = 'Počiatočná ACL politika';
$lang['i_pol0']                = 'Otvorená Wiki (čítanie, zápis a nahrávanie pre každého)';
$lang['i_pol1']                = 'Verejná Wiki (čítanie pre každého, zápis a nahrávanie pre registrovaných používateľov)';
$lang['i_pol2']                = 'Uzatvorená Wiki (čítanie, zápis a nahrávanie len pre registrovaných používateľov)';
$lang['i_allowreg']            = 'Povolenie samostanej registrácie používateľov';
$lang['i_retry']               = 'Skúsiť znovu';
$lang['i_license']             = 'Vyberte licenciu, pod ktorou chcete uložiť váš obsah:';
$lang['i_license_none']        = 'Nezobrazovať žiadne licenčné informácie';
$lang['i_pop_field']           = 'Prosím pomôžte nám zlepšiť prácu s DokuWiki:';
$lang['i_pop_label']           = 'Raz mesačne zaslať anonymné údaje vývojárom DokuWiki';
$lang['recent_global']         = 'Práve prehliadate zmeny v mennom priestore <b>%s</b>. Môžete si tiež pozrieť <a href="%s">aktuálne zmeny celej wiki</a>.';
$lang['years']                 = 'pred %d rokmi';
$lang['months']                = 'pred %d mesiacmi';
$lang['weeks']                 = 'pred %d týždňami';
$lang['days']                  = 'pred %d dňami';
$lang['hours']                 = 'pred %d hodinami';
$lang['minutes']               = 'pred %d minútami';
$lang['seconds']               = 'pred %d sekundami';
$lang['wordblock']             = 'Vaše zmeny neboli uložené, pretože obsahovali nepovolený text (spam).';
$lang['media_uploadtab']       = 'Nahrať';
$lang['media_searchtab']       = 'Hľadať';
$lang['media_file']            = 'Súbor';
$lang['media_viewtab']         = 'Náhľad';
$lang['media_edittab']         = 'Upraviť';
$lang['media_historytab']      = 'História';
$lang['media_list_thumbs']     = 'Miniatúry';
$lang['media_list_rows']       = 'Zoznam';
$lang['media_sort_name']       = 'Meno';
$lang['media_sort_date']       = 'Dátum';
$lang['media_namespaces']      = 'Vybrať priestor';
$lang['media_files']           = 'Súbory v %s';
$lang['media_upload']          = 'Nahrať do %s';
$lang['media_search']          = 'Hľadať v %s';
$lang['media_view']            = '%s';
$lang['media_viewold']         = '%s v %s';
$lang['media_edit']            = 'Upraviť %s';
$lang['media_history']         = 'História %s';
$lang['media_meta_edited']     = 'metadáta upravené';
$lang['media_perm_read']       = 'Prepáčte, ale nemáte dostatočné oprávnenie na čítanie súborov.';
$lang['media_perm_upload']     = 'Prepáčte, ale nemáte dostatočné oprávnenie na nahrávanie súborov.';
$lang['media_update']          = 'Nahrať novú verziu';
$lang['media_restore']         = 'Obnoviť túto verziu';
$lang['media_acl_warning']     = 'Tento zoznam nemusí byť úplný z dôvodu ACL obmedzení alebo skratých stránok.';
$lang['currentns']             = 'Aktuálny menný priestor';
$lang['searchresult']          = 'Výsledky hľadania';
$lang['plainhtml']             = 'Jednoduché HTML';
$lang['wikimarkup']            = 'Wiki formát';
$lang['page_nonexist_rev']     = 'Stránka %s neexistovala. Bola vytvorená dodatočne <a href="%s">%s</a>.';
$lang['unable_to_parse_date']  = 'Nie je možné spracovať parameter "%s".';
$lang['email_signature_text']  = 'Táto správa bola zaslaná DokuWiki
@DOKUWIKIURL@';
